@@ -1,5 +1,4 @@
 from canvy.scripts.downloader import download
 from canvy.scripts.grades import grades, grades_by_course
-from canvy.scripts.teacher import teacher
 
-__all__ = ["download", "grades", "grades_by_course", "teacher"]
+__all__ = ["download", "grades", "grades_by_course"]
